"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpDataLoader = void 0;
const axios_1 = require("axios");
const lodash_1 = require("lodash");
const paramsSerializer = (params) => {
    const parts = [];
    (0, lodash_1.forEach)(params, (value, key) => {
        if (value === null || typeof value === 'undefined') {
            return;
        }
        let k = key;
        let v = value;
        if (Array.isArray(v)) {
            k += '[]';
        }
        else {
            v = [v];
        }
        (0, lodash_1.forEach)(v, (val) => {
            let finalValue = val;
            if ((0, lodash_1.isObject)(finalValue)) {
                finalValue = JSON.stringify(finalValue);
            }
            parts.push(`${k}=${finalValue}`);
        });
    });
    return parts.join('&');
};
class HttpDataLoader {
    constructor(config) {
        this.config = config;
    }
    async load(req) {
        try {
            const { data, status, headers } = await axios_1.default.request({
                baseURL: this.config.config.endpoint,
                validateStatus: (status) => false,
                url: req.resourcePath,
                headers: req.params.headers,
                params: req.params.query,
                paramsSerializer,
                method: req.method.toLowerCase(),
                data: req.params.body,
            });
            return {
                headers,
                statusCode: status,
                body: JSON.stringify(data),
            };
        }
        catch (err) {
            console.log(err);
        }
        return null;
    }
}
exports.HttpDataLoader = HttpDataLoader;
//# sourceMappingURL=http-data-loader.js.map